@@ -11,8 +11,9 @@ from io import BytesIO, StringIO
 from pathlib import Path
 from uuid import uuid4
 
-import tablib
 from MarkupPy import markup
+
+import tablib
 from tablib.core import Row, detect_format
 from tablib.exceptions import UnsupportedFormat
 from tablib.formats import registry
@@ -57,7 +58,7 @@ class TablibTestCase(BaseTestCase):
         # A known format but uninstalled
         del registry._formats['ods']
         msg = (r"The 'ods' format is not available. You may want to install the "
-               "odfpy package \\(or `pip install tablib\\[ods\\]`\\).")
+               "odfpy package \\(or `pip install \"tablib\\[ods\\]\"`\\).")
         with self.assertRaisesRegex(UnsupportedFormat, msg):
             data.export('ods')
 
@@ -659,6 +660,7 @@ class RSTTests(BaseTestCase):
         data.headers = self.headers
         data.append(self.john)
         data.append(('Wendy', '', 43))
+        data.append(('Esther', ' ', 31))
         self.assertEqual(
             data.export('rst'),
             '==========  =========  ===\n'
@@ -666,6 +668,7 @@ class RSTTests(BaseTestCase):
             '==========  =========  ===\n'
             'John        Adams      90 \n'
             'Wendy                  43 \n'
+            'Esther                 31 \n'
             '==========  =========  ==='
         )
 
@@ -1037,6 +1040,13 @@ class XLSXTests(BaseTestCase):
             data = tablib.Dataset().load(fh)
         self.assertEqual(data.headers[0], 'Hello World')
 
+    def test_xlsx_bad_dimensions(self):
+        """Test loading file with bad dimension.  Must be done with
+        read_only=False."""
+        xls_source = Path(__file__).parent / 'files' / 'bad_dimensions.xlsx'
+        with xls_source.open('rb') as fh:
+            data = tablib.Dataset().load(fh, read_only=False)
+        self.assertEqual(data.height, 3)
 
 class JSONTests(BaseTestCase):
     def test_json_format_detect(self):
@@ -1086,11 +1096,13 @@ class JSONTests(BaseTestCase):
         headers = self.headers + ('address_id',)
         founders = tablib.Dataset(headers=headers, title='Founders')
         founders.append(('John', 'Adams', 90, address_id))
+        founders.append(('名字', '李', 60, ''))
         founders_json = founders.export('json')
 
         expected_json = (
             '[{"first_name": "John", "last_name": "Adams", "gpa": 90, '
-            '"address_id": "%s"}]' % str(address_id)
+            '"address_id": "%s"}, {"first_name": "名字", "last_name": "李", '
+            '"gpa": 60, "address_id": ""}]' % str(address_id)
         )
 
         self.assertEqual(founders_json, expected_json)
@@ -1143,10 +1155,12 @@ class YAMLTests(BaseTestCase):
     def test_yaml_export(self):
         """YAML export"""
 
+        self.founders.append(('名字', '李', 60))
         expected = """\
 - {first_name: John, gpa: 90, last_name: Adams}
 - {first_name: George, gpa: 67, last_name: Washington}
 - {first_name: Thomas, gpa: 50, last_name: Jefferson}
+- {first_name: 名字, gpa: 60, last_name: 李}
 """
         output = self.founders.yaml
         self.assertEqual(output, expected)
